/**
 * Copyright 2016 Reza (github.com/rghorbani)
 *
 * @flow
 */

'use strict';

const React = require('react');
const PropTypes = require('prop-types');
const hoistNonReactStatic = require('hoist-non-react-statics');
const _ = require('lodash');
const RNImage = require('react-native').Image;

const Assets = require('../../assets');
const { BaseComponent } = require('../../commons');
const { ThemeManager } = require('../../style');

/**
 * @description: Image wrapper with extra functionality like source transform and assets support
 * @extends: Image
 * @extendslink: https://facebook.github.io/react-native/docs/image.html
 */
class Image extends BaseComponent {
  static displayName = 'Image';

  static propTypes = {
    /**
     * custom source transform handler for manipulating the image source (great for size control)
     */
    sourceTransformer: PropTypes.func,
    /**
     * if provided image source we be drriven from asset name
     */
    assetName: PropTypes.string,
    /**
     * the asset group, default is "icons"
     */
    assetGroup: PropTypes.string,
  };

  static defaultProps = {
    assetGroup: 'icons',
  };

  constructor(props) {
    super(props);

    this.sourceTransformer =
      props.sourceTransformer ||
      _.get(ThemeManager.components, 'Image.sourceTransformer');
  }

  getImageSource() {
    const { assetName, assetGroup } = this.props;
    if (!_.isUndefined(assetName)) {
      return _.get(Assets, `${assetGroup}.${assetName}`);
    }

    if (this.sourceTransformer) {
      return this.sourceTransformer(this.props);
    }

    const { source } = this.props;
    if (_.get(source, 'uri') === null || _.get(source, 'uri') === '') {
      return { ...source, uri: undefined };
    }

    return source;
  }

  render() {
    const source = this.getImageSource();
    return <RNImage {...this.props} source={source} />;
  }
}

hoistNonReactStatic(Image, RNImage);

module.exports = Image;
